#!/bin/bash

Help(){
cat<<EOH
##
## RaidLogicalVolumeAllAroundScript
##
#
#  Help:

You're supposed to pass some parameters:

-l 'NAME'           # This would be the name of the logical volume (eg. lg_opt)
-v 'NAME'           # This would be the name of the volume group (eg. bg_opt)
-d 'list,devices'   # This would contain the list of the devices separated by comma 

-m 'NAME'           # This would be the name of the raid device (eg. opt)
-r 'Type_of_Raid'   # At this point you can only use mirror or strip

The first three are mandatory.

Example:
$0 -d xvdb,xvdc -v VgName -l LvName -m opt -r mirror

EOH

}


Debug(){
    echo "It's all ok so far - Just because you know:"
    for a in PhysicalDevice Devices RaidDev1 RaidDev2 LogVolName  VolGrpName  RaidType  MirrorName 
    do 
        printf "%15s -> %15s <-\n" "$a" "$(eval echo \$$a | hexdump -C | head -1 )"
    done
    echo ""

}

Error(){
    echo ""
    echo "    ######################################################"
    echo "      Error: $1"
    echo "    ######################################################"
    echo ""
    #Debug
    echo ""
    Help
    exit 1
}



unset PhisicalDevice
unset Devices
unset LogVolName
unset VolGrpName
unset RaidType
unset MirrorName


while getopts ":d:l:v:m:r:" FLAG; do
  case $FLAG in
    d) Devices="$OPTARG" 
      ;;
      
    l) LogVolName="$OPTARG"
      ;;
      
    m) MirrorName="$OPTARG"
      ;;
      
    r) RaidType="$OPTARG" 
      ;;
      
    v) VolGrpName="$OPTARG"
      ;;
    h|*) help
      ;;
      
  esac
done


NumberDevices=$(echo $Devices | tr ',' ' ' | awk '{print NF}')

if [ ${NumberDevices} -lt 1 ]
then
    Error "Not enough devices to be honest"
fi

case $NumberDevices in
    1) PhisicalDevice="/dev/$(echo $Devices | tr -d ',')"
        ;;
    2) RaidDev1="$(echo $Devices | cut -d ',' -f 1)"
       RaidDev2="$(echo $Devices | cut -d ',' -f 2)"
       if [ "${RaidDev1}" == "${RaidDev2}" ]
       then 
            Error "Apparently the two devices are only one, so..."
       fi
        ;;
    *) Error "Not sure what you mean, ${NumberDevices} device(s)? For a Raid1?"
        ;;
esac


if [ -z ${LogVolName} ]
then
    Error "LogicalVolume Name Missing!"
fi

if [ -z ${VolGrpName} ]
then
    Error "VolumeGroup Name Missing!"
fi

#Debug


if [[ "x${RaidType}" != "x" ]]
then   
    if [ -z ${MirrorName} ]
    then
        Error "Mirror Name Missing"
    fi
    if [ ${NumberDevices} -ne 2 ]
    then
        Error "Probably the wrong number of Devices?"
    fi
    
    echo yes | mdadm --quiet --create /dev/md/${MirrorName} --level=${RaidType} --raid-devices=2 /dev/$RaidDev1 /dev/$RaidDev2
    
    if [ $? -ne 0 ]
    then
        Error "Something is Wrong on Internet Raid..."
    fi
    
    PhisicalDevice="/dev/${MirrorName}"
else    
    if [ ${NumberDevices} -eq 2 ]
    then
        Error "Probably the wrong number of Devices? For ${NumberDevices} for without a Raid?"
    fi
fi

#Debug 

pvcreate ${PhisicalDevice}
vgcreate ${VolGrpName} ${PhisicalDevice}
lvcreate -l 100%FREE -n ${LogVolName} ${VolGrpName}
echo , | sfdisk /dev/mapper/${VolGrpName}-${LogVolName} 
mkfs.ext4 -F /dev/mapper/${VolGrpName}-${LogVolName}
