#
# Cookbook Name:: base_install
# Recipe:: bmi_aws_dns
#
# Copyright (c) 2015 The Authors, All Rights Reserved.
include_recipe 'python'

python_pip 'cli53' 

config = Chef::EncryptedDataBagItem.load('aws', 'aws_config')

directory '/etc/route53' do
  owner 'root'
  group 'root'
  mode '0700'
  action :create
end

template '/etc/route53/config' do
  source 'aws_dns_config.erb'
  owner 'root'
  group 'root'
  variables(
    aws_key: config['AWS_ACCESS_KEY_ID'],
    aws_secret_key: config['AWS_SECRET_ACCESS_KEY'],
    zone: "aws.bmidomain.com",
    ttl: "600"
    )
  mode '0600'
end

template '/etc/boto.cfg' do
  source 'boto.cfg.erb'
  owner 'root'
  group 'root'
  variables(
    aws_key: config['AWS_ACCESS_KEY_ID'],
    aws_secret_key: config['AWS_SECRET_ACCESS_KEY']
    )
  mode '0600'
end

cookbook_file '/usr/local/bin/update-route53-dns' do
  source 'aws_dns'
  owner 'root'
  group 'root'
  mode '0744'
end

link '/etc/dhcp/dhclient.d/update-route53-dns' do
  to '/usr/local/bin/update-route53-dns'
end

# create stamp after first run
file "/etc/chef/stamps/aws_dns.stamp" do
  owner "root"
  group "root"
  mode "0700"
  action :nothing
end

bash 'run dns once' do
  not_if { ::File.exist?("/etc/chef/stamps/aws_dns.stamp") }
  code <<-EOH
  . /etc/route53/config
  cli53 rrcreate "$ZONE" $(hostname) A $(curl -s -L 169.254.169.254/latest/meta-data/local-ipv4) --ttl 600 --replace
  EOH
  notifies :create, "file[/etc/chef/stamps/aws_dns.stamp]"
end
