#
# Cookbook Name:: base_install-0.1.#
# Recipe:: home_dir
#
# Copyright (c) 2015 The Authors, All Rights Reserved.

directory '/users' do
  owner 'root'
  group 'root'
  mode '0755'
  action :create
end

users = data_bag('users')

begin
  env = node.chef_environment.downcase
  config = Chef::EncryptedDataBagItem.load(env, node['suffix'])
  node.default_unless['nfs'] = config['nfs']
  mount_point = '/users'

  package 'nfs-utils' do
    action :install
    ignore_failure true
  end

  mount "#{mount_point}" do
    device "#{node['nfs']}:/users"
    fstype 'nfs4'
    options '_netdev,rw,hard,intr,noatime,timeo=50,retrans=10'
    # if node['platform_version'].to_i == 7 || node['platform'] == 'amazon'
    action [:nothing, :enable]  
    # end
  end

  Chef::Log.info("This is #{env} Instance /users NFS has been mounted")
rescue
  Chef::Log.info('This is internal Instance and No NFS')
end

users.delete('clearcache')
users.each do |user|
  users_status = Mixlib::ShellOut.new("id #{user}")
  users_status.run_command

  if users_status.status.success?
    home_dir = "/users/#{user}"
    groups = data_bag_item('users', user)['groups']
    ssh_keys = data_bag_item('users', user)['ssh_keys']

    directory home_dir do
      owner user
      group groups[0]
      mode '0750'
      action :create
    end

    directory "#{home_dir}/.ssh" do
      owner user
      group groups[0]
      mode '0700'
      action :create
    end

    # TODO: Make shure is it works
    %w( bash_profile bashrc bash_logout ).each do |file|
      cookbook_file "#{home_dir}/.#{file}" do
        source file
        owner user
        group 'bmint'
        mode 0644
        # content ::File.open("/etc/skel/#{file}").read
        action :create
      end
    end

    file "#{home_dir}/.ssh/authorized_keys" do
      owner user
      group 'bmint'
      content ssh_keys
      mode 0600
      action :create
    end
    # end of TODO
  else
    Chef::Log.warn("Users not found!!!")
  end
end

# TODO: find a way to resolve warnings
ruby_block '/etc/pam.d/sshd' do
  block do
    file = Chef::Util::FileEdit.new('/etc/pam.d/sshd')
    file.insert_line_if_no_match('home_creation.sh', 'session optional pam_exec.so /usr/local/bin/home_creation.sh')
    file.write_file
  end
  not_if { File.readlines('/etc/pam.d/sshd').grep(/home_creation/).size > 0 }
end

cookbook_file '/usr/local/bin/home_creation.sh' do
  source 'home_creation.sh'
  mode '0755'
end
