
# delete old repos and install new
if node['platform_version'].to_i == 5
  file '/etc/yum.repos.d/bmi-rhel5.repo' do
    action :delete
  end

  file '/etc/yum.repos.d/epel.repo' do
    action :delete
  end
end

#   install common repos for all services
%w( bmi_cms bmi_rsd ).each do |repo|
  yum_repository repo do
    description 'Red Hat Enterprise $releasever - BMI - OS'
    baseurl "http://yum.businessmonitor.com/redhat/el5/en/$basearch/#{repo.gsub(/.*_/, '')}"
    gpgcheck false
    action :create
  end
end

#   install bmo repos for all services only if we're not in AWS
%w( bmi_bmo bmi_bmo5 ).each do |repo|
  if node['platform'] != 'amazon'
    yum_repository repo do
      description 'Red Hat Enterprise $releasever - BMI - OS'
      baseurl "http://yum.businessmonitor.com/redhat/el5/en/$basearch/#{repo.gsub(/.*_/, '')}"
      gpgcheck false
      action :create
    end
  else
    file "/etc/yum.repos.d/#{repo}.repo" do
      action :delete
    end
  end
end

yum_repository 'bmi_apps' do
  description 'Red Hat Enterprise $releasever - BMI - OS'
  baseurl 'http://yum.businessmonitor.com/redhat/el5/en/$basearch/apps'
  exclude 'php* httpd* sphinx*'
  gpgcheck false
  action :create
end

# install epel only for centos 7
unless node['platform_version'].to_i == 5
  include_recipe 'yum-epel'
  yum_repository 'epel' do
  end
end

if node['platform'] == 'amazon'
  yum_repository 'aws' do
    description 'BMO AWS Repositories'
    baseurl 'http://yum-aws.businessmonitor.com/redhat/el5/en/$basearch/aws'
    gpgcheck false
    action :create
  end
end

# yum_repository 'rhel_os' do
#   description 'Red Hat Enterprise $releasever - BMI - OS'
#   baseurl 'http://yum.businessmonitor.com/redhat/el5/en/$basearch/os'
#   gpgcheck false
#   action :create
# end

# Install 3rd party packages
packages = node['base_install']['3rdparty']['packages']
packages.each do |pkg|
  package pkg do
    action :install
    ignore_failure true
  end
end
